==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/chimesdkmediapipelines/kotlin/inputs/MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.chimesdkmediapipelines.kotlin.inputs

import com.pulumi.aws.chimesdkmediapipelines.inputs.MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property insightsTarget SQS queue to deliver results.
 */
public data class MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs(
    public val insightsTarget: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.chimesdkmediapipelines.inputs.MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs> {
    override fun toJava():
        com.pulumi.aws.chimesdkmediapipelines.inputs.MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs =
        com.pulumi.aws.chimesdkmediapipelines.inputs.MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs.builder()
            .insightsTarget(insightsTarget.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs].
 */
@PulumiTagMarker
public class MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgsBuilder
internal constructor() {
    private var insightsTarget: Output<String>? = null

    /**
     * @param value SQS queue to deliver results.
     */
    @JvmName("ttopdxadyhkiygsf")
    public suspend fun insightsTarget(`value`: Output<String>) {
        this.insightsTarget = value
    }

    /**
     * @param value SQS queue to deliver results.
     */
    @JvmName("kcoyvywbrxnndgtc")
    public suspend fun insightsTarget(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.insightsTarget = mapped
    }

    internal fun build():
        MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs =
        MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs(
            insightsTarget = insightsTarget ?: throw PulumiNullFieldException("insightsTarget"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/chimesdkmediapipelines/kotlin/inputs/MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.chimesdkmediapipelines.kotlin.inputs

import com.pulumi.aws.chimesdkmediapipelines.inputs.MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property insightsTarget Kinesis Data Stream to deliver results.
 */
public data class MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs(
    public val insightsTarget: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.chimesdkmediapipelines.inputs.MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.chimesdkmediapipelines.inputs.MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs =
        com.pulumi.aws.chimesdkmediapipelines.inputs.MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs.builder()
            .insightsTarget(insightsTarget.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs].
 */
@PulumiTagMarker
public class MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgsBuilder
internal constructor() {
    private var insightsTarget: Output<String>? = null

    /**
     * @param value Kinesis Data Stream to deliver results.
     */
    @JvmName("qvixbwnhegbkcywg")
    public suspend fun insightsTarget(`value`: Output<String>) {
        this.insightsTarget = value
    }

    /**
     * @param value Kinesis Data Stream to deliver results.
     */
    @JvmName("rtqsjifemnbvhknv")
    public suspend fun insightsTarget(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.insightsTarget = mapped
    }

    internal fun build(): MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs =
        MediaInsightsPipelineConfigurationElementKinesisDataStreamSinkConfigurationArgs(
            insightsTarget = insightsTarget ?: throw PulumiNullFieldException("insightsTarget"),
        )
}
